//
//  PokktInterstitialVC.m
//  PokktDemoApp
//
//  Created by Suraj Singh on 16/05/18.
//  Copyright © 2018 Suraj Singh. All rights reserved.
//

#import "PokktInterstitialVC.h"
#import "PokktUtility.h"

#define EarnedPoints @"IntPoints"
#define userDefaluts [NSUserDefaults standardUserDefaults]

@interface PokktInterstitialVC ()
@property (nonatomic) float points;
@end

@implementation PokktInterstitialVC

- (void)viewDidLoad {
    [super viewDidLoad];
     [self updateEarnedPoints];
    
    logoImg.transform = CGAffineTransformMakeRotation(-M_1_PI);
    // Do any additional setup after loading the view.
    
    [self configurePokktSDK];
}

-(void)configurePokktSDK
{
    NSUserDefaults *settings = [NSUserDefaults standardUserDefaults];
    
    NSString *appId = [settings objectForKey:@"appId"];
    NSString *securityKey = [settings objectForKey:@"secKey"];
    
    /**
     * In [PokktAds setPokktConfig: securityKey:]
     * Replace "AppID" and "SecurityKey"  with the one assigned to you by Pokkt.
     *
     */
    
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // optional, set it to true if you want to enable logs for PokktSDK
    
    [PokktDebugger setDebug:YES];
    
    // OPTIONAL but we SUGGEST you to implement delegates as it will help you to determine the status of your request
    
    [PokktInterstitial setPokktInterstitialDelegate:self];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(IBAction)cacheRewardedInterstitialAd:(id)sender
{
    [PokktUtility addSpinnerOnButton:cacheRewardedBtn];
    [PokktInterstitial cacheRewarded:screenTF.text];

}

-(IBAction)showRewardedInterstitialAd:(id)sender
{
    [PokktInterstitial showRewarded:screenTF.text withViewController:self];
}

-(IBAction)cacheNonRewardedInterstitialAd:(id)sender
{
    [PokktUtility addSpinnerOnButton:cacheNonRewardedBtn];
    [PokktInterstitial cacheNonRewarded:screenTF.text];
}

-(IBAction)showNonRewardedInterstitialAd:(id)sender
{
    [PokktInterstitial showNonRewarded:screenTF.text withViewController:self];
}

#pragma mark Pokkt Interstitial Ads Delegates

- (void)interstitialCachingCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded reward: (float)reward
{
    [PokktUtility stopSpinner:cacheRewardedBtn];
    [PokktUtility stopSpinner:cacheNonRewardedBtn];
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad caching complete for %@ with reward point is %f",screenName,reward];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)interstitialCachingFailed: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    [PokktUtility stopSpinner:cacheRewardedBtn];
    [PokktUtility stopSpinner:cacheNonRewardedBtn];
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad caching failed for %@ with error is %@",screenName,errorMessage];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)interstitialCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded;
{
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad complete for %@",screenName];
    
    [PokktDebugger showToast:msg viewController:self];
}

- (void)interstitialDisplayed: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad displayed for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)interstitialClicked: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad Clicked for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)interstitialGratified: (NSString *)screenName reward:(float)reward
{
    if([userDefaluts objectForKey:EarnedPoints])
    {
        self.points = [[userDefaluts objectForKey:EarnedPoints] floatValue];
    }
    if (reward > 0)
    {
        self.points += reward;
        [userDefaluts setValue:[NSString stringWithFormat:@"%f",self.points] forKey:EarnedPoints];
        [userDefaluts synchronize];
        [self updateEarnedPoints];
    }
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad gratified for %@ with reward is %f",screenName,reward];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)interstitialSkipped: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad skipper for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
    
}

- (void)interstitialClosed:(NSString *)screenName isRewarded: (BOOL)isRewarded
{
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad closed for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
    
}

- (void)interstitialAvailabilityStatus: (NSString *)screenName isRewarded: (BOOL)isRewarded isAdAvailable: (BOOL)isAdAvailable
{
    NSString *statusString = @"is available";
    if (!isAdAvailable) {
        statusString = @"is not available";
    }
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad %@ for %@",statusString,screenName];
   [PokktDebugger showToast:msg viewController:self];
}

- (void)interstitialFailedToShow: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    NSString *msg = [NSString stringWithFormat:@"Interstitial ad falied to show for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
}

#pragma mark Textfield Delegate Method

- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [textField resignFirstResponder];
    return YES;
}

- (void)updateEarnedPoints
{
    if([userDefaluts objectForKey:EarnedPoints])
    {
        self.points = [[userDefaluts objectForKey:EarnedPoints] floatValue];
        self.rewardPointLabel.text = [NSString stringWithFormat:@"Earned Points: %.02f",self.points];
    }
}

@end
