//
//  PokktVideoVC.m
//  PokktDemoApp
//
//  Created by Suraj Singh on 16/05/18.
//  Copyright © 2018 Suraj Singh. All rights reserved.
//

#import "PokktVideoVC.h"
#import "PokktUtility.h"


#define EarnedPoints @"Points"
#define userDefaluts [NSUserDefaults standardUserDefaults]

@interface PokktVideoVC ()
@property (nonatomic) float points;
@end

@implementation PokktVideoVC

- (void)viewDidLoad {
    [super viewDidLoad];
    [self updateEarnedPoints];

    
    logoImg.transform = CGAffineTransformMakeRotation(-M_1_PI);
    // Do any additional setup after loading the view.
    
    [self configurePokktSDK];
}



- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(void)configurePokktSDK
{
    NSUserDefaults *settings = [NSUserDefaults standardUserDefaults];
    
    NSString *appId = [settings objectForKey:@"appId"];
    NSString *securityKey = [settings objectForKey:@"secKey"];
    
    /**
     * In [PokktAds setPokktConfig: securityKey:]
     * Replace "AppID" and "SecurityKey"  with the one assigned to you by Pokkt.
     *
     */
    
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // optional, set it to true if you want to enable logs for PokktSDK
    
    [PokktDebugger setDebug:YES];
    
    // OPTIONAL but we SUGGEST you to implement delegates as it will help you to determine the status of your request
    
    [PokktVideoAds setPokktVideoAdsDelegate:self];
    
    [PokktAds callBackgroundTaskCompletedHandler:^(UIBackgroundFetchResult result) {
        NSLog(@"%lu",(unsigned long)result);
    }];
}

#pragma mark UIButton Actions

-(IBAction)cacheRewardedVideoAd:(id)sender
{
    [PokktUtility addSpinnerOnButton:cacheRewardedBtn];
    [PokktVideoAds cacheRewarded:screenTF.text];
}

-(IBAction)showRewardedVideoAd:(id)sender
{
    [PokktVideoAds showRewarded:screenTF.text withViewController:self];
}

-(IBAction)cacheNonRewardedVideoAd:(id)sender
{
    [PokktUtility addSpinnerOnButton:cacheNonRewardedBtn];
    [PokktVideoAds cacheNonRewarded:screenTF.text];
}

-(IBAction)showNonRewardedVideoAd:(id)sender
{
    [PokktVideoAds showNonRewarded:screenTF.text withViewController:self];
}

#pragma mark Pokkt Video Ads Delegates

- (void)videoAdCachingCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded reward: (float)reward
{
    [PokktUtility stopSpinner:cacheNonRewardedBtn];
    [PokktUtility stopSpinner:cacheRewardedBtn];
    
    NSString *msg = [NSString stringWithFormat:@"Video ad caching complete for %@ with reward point is %f",screenName,reward];
 
    [PokktDebugger showToast:msg viewController:self];
 
}

- (void)videoAdCachingFailed: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    [PokktUtility stopSpinner:cacheNonRewardedBtn];
    [PokktUtility stopSpinner:cacheRewardedBtn];
    NSString *msg = [NSString stringWithFormat:@"Video ad caching failed for %@ with error is %@",screenName,errorMessage];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)videoAdCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    NSString *msg = [NSString stringWithFormat:@"Video ad complete for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)videoAdDisplayed: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    NSString *msg = [NSString stringWithFormat:@"Video ad displayed for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)videoAdClicked: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    NSString *msg = [NSString stringWithFormat:@"Video ad Clicked for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)videoAdGratified: (NSString *)screenName reward:(float)reward
{
    if([userDefaluts objectForKey:EarnedPoints])
    {
        self.points = [[userDefaluts objectForKey:EarnedPoints] floatValue];
    }
    if (reward > 0)
    {
        self.points += reward;
        [userDefaluts setValue:[NSString stringWithFormat:@"%f",self.points] forKey:EarnedPoints];
        [userDefaluts synchronize];
        [self updateEarnedPoints];
    }
    NSString *msg = [NSString stringWithFormat:@"Video ad gratified for %@ with reward is %f",screenName,reward];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)videoAdSkipped: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    NSString *msg = [NSString stringWithFormat:@"Video ad skipper for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)videoAdClosed:(NSString *)screenName isRewarded: (BOOL)isRewarded
{
    NSString *msg = [NSString stringWithFormat:@"Video ad closed for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)videoAdAvailabilityStatus: (NSString *)screenName isRewarded: (BOOL)isRewarded isAdAvailable: (BOOL)isAdAvailable
{
    NSString *statusString = @"is available";
    if (!isAdAvailable) {
        statusString = @"is not available";
    }
    if (isAdAvailable) {
        
    }
    NSString *msg = [NSString stringWithFormat:@"Video ad %@ for %@",statusString,screenName];
   [PokktDebugger showToast:msg viewController:self];
}

- (void)videoAdFailedToShow: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    NSString *msg = [NSString stringWithFormat:@"Video ad falied to show for %@",screenName];
    [PokktDebugger showToast:msg viewController:self];
}

#pragma mark Textfield Delegate Method

- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [textField resignFirstResponder];
    return YES;
}


- (void)updateEarnedPoints
{
    if([userDefaluts objectForKey:EarnedPoints])
    {
        self.points = [[userDefaluts objectForKey:EarnedPoints] floatValue];
        self.rewardPointLabel.text = [NSString stringWithFormat:@"Earned Points: %.02f",self.points];
    }
}
@end
